### <a name="manual"></a> Value block

Allows to extract single value from resource without using foreach block.


| Key       |      Description      | Default |
|:----------|:--------------------- |:-------------- |
| type      |  value                |  
| resource  |  expression for extraction of value from resource     |




Example:
```YAML
- type        : value
  resource    : data01/field01

```

Back to [Documentation](../../../README.md#block_data)
